%error = forceRequiredAddOn("Projectile_GravityRocket");
if(%error == $Error::AddOn_Disabled)
	 gravityRocketProjectile.uiName = "";
if(%error == $Error::AddOn_NotFound)
	 return error("ERROR: Weapon_Mortar - required add-on Projectile_GravityRocket not found");
datablock ParticleData(MortarSmokeParticle)
{
	dragCoefficient = 3;
	gravityCoefficient = -0.5;
	inheritedVelFactor = 0.2;
	constantAcceleration = 0.0;
	lifetimeMS = 525;
	lifetimeVarianceMS = 55;
	textureName = "base/data/particles/cloud";
	spinSpeed = 10.0;
	spinRandomMin = -500.0;
	spinRandomMax = 500.0;
	colors[0] = "0.5 0.5 0.5 0.9";
	colors[1] = "0.5 0.5 0.5 0.0";
	sizes[0] = 0.15;
	sizes[1] = 0.15;
	useInvAlpha = false;
};
datablock ParticleEmitterData(MortarSmokeEmitter)
{
	 ejectionPeriodMS = 3;
	 periodVarianceMS = 0;
	 ejectionVelocity = 1.0;
	 velocityVariance = 1.0;
	 ejectionOffset = 0.0;
	 thetaMin = 0;
	 thetaMax = 90;
	 phiReferenceVel = 0;
	 phiVariance = 360;
	 overrideAdvance = false;
	 particles = "MortarSmokeParticle";
	 uiName = "Mortar Smoke";
};

datablock AudioProfile(MortarSound)
{
	filename = "./whistle.wav";
	description = AudioClose3d;
	preload = true;
};
datablock AudioProfile(MortarFireSound)
{
	filename = "./Fire.wav";
	description = AudioClose3d;
	preload = true;
};
datablock ProjectileData(MortarProjectile)
{
	 projectileShapeName = "./Projectile.dts";
	 directDamage = 30;
	 directDamageType = $DamageType::RocketDirect;
	 radiusDamageType = $DamageType::RocketRadius;
	 impactImpulse = 1000;
	 verticalImpulse = 1000;
	 explosion = gravityRocketExplosion;
	 particleEmitter = MortarSmokeEmitter;
	 brickExplosionRadius = 3;
	 brickExplosionImpact = false;					//destroy a brick if we hit it directly?
	 brickExplosionForce = 30;						 
	 brickExplosionMaxVolume = 30;					//max volume of bricks that we can destroy
	 brickExplosionMaxVolumeFloating = 60;	//max volume of bricks that we can destroy if they aren't connected to the ground (should always be >= brickExplosionMaxVolume)
	 sound = MortarSound;
	 muzzleVelocity = 65;
	 velInheritFactor = 1.0;
	 armingDelay = 00;
	 lifetime = 12000;
	 fadeDelay = 11500;
	 bounceElasticity = 0.5;
	 bounceFriction = 0.20;
	 isBallistic = true;
	 gravityMod = 1.0;
	 hasLight = true;
	 lightRadius = 5.0;
	 lightColor = "1 0.5 0.0";
	 uiName = "Mortar Shell";
};
datablock ItemData(MortarItem)
{
	category = "Weapon";
	className = "Weapon";
	shapeFile = "./Launcher.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;
	uiName = "Mortar";
	iconName = "./icon_Mortar";
	doColorShift = true;
	colorShiftColor = "0.100 0.500 0.250 1.000";
	image = MortarImage;
	canDrop = true;
};
datablock ShapeBaseImageData(MortarImage)
{
	shapeFile = "./Launcher.dts";
	emap = true;
	mountPoint = 0;
	offset = "0 0 0";
	eyeOffset = "0.515 1 -1.1"; //"0.7 1.2 -0.5";
	rotation = eulerToMatrix("0 0 0");
	correctMuzzleVector = true;
	className = "WeaponImage";
	item = MortarItem;
	ammo = " ";
	projectile = MortarProjectile;
	projectileType = Projectile;
	melee = false;
	armReady = true;
	doColorShift = true;
	colorShiftColor = MortarItem.colorShiftColor;
	stateName[0] = "Activate";
	stateSequence[0] = "FireReady";
	stateTransitionOnTimeout[0] = "Ready";
	stateSound[0] = weaponSwitchSound;

	stateName[1] = "Ready";
	stateTransitionOnTriggerDown[1] = "Check1";
	stateAllowImageChange[1] = true;
	stateTimeoutValue[1] = 0.01;

	stateName[2] = "Check1";
	stateScript[2] = "onCheckFire";
	stateTimeoutValue[2] = 0.14;
	stateTransitionOnTimeout[2] = "Check2";

	stateName[3] = "Check2";
	stateTimeoutValue[3] = 0.14;
	stateTransitionOnAmmo[3] = "Fire";
	stateTransitionOnNoAmmo[3] = "Ready";

	stateName[4] = "Fire";
	stateTransitionOnTimeout[4] = "Smoke";
	stateTimeoutValue[4] = 0.14;
	stateFire[4] = true;
	stateAllowImageChange[4] = false;
	stateSequence[4] = "Fire";
	stateScript[4] = "onFire";
	stateWaitForTimeout[4] = true;
	stateSound[4] = MortarFireSound;

	stateName[5] = "Smoke";
	stateEmitter[5] = MortarSmokeEmitter;
	stateEmitterTime[5] = 0.1;
	stateEmitterNode[5] = "muzzleNode";
	stateTransitionOnTimeout[5] = "Ready";
	stateTimeoutValue[5] = 0.14;
};
function MortarImage::onCheckFire(%this,%obj,%slot)
{
	if(%obj.lastMortarFire !$= "" && getSimTime() - %obj.lastMortarFire < 4000)
		%obj.setImageAmmo(0,0);
	else
		%obj.setImageAmmo(0,1);
}
function MortarImage::onFire(%this,%obj,%slot)
{
	%dist = 100;
	%range = 300*getWord(%obj.getScale(),2);
	%start = %obj.getEyePoint();
	%fvec = %obj.getForwardVector();
	%fX = getWord(%fvec,0);
	%fY = getWord(%fvec,1);
	%evec = %obj.getEyeVector();
	%eX = getWord(%evec,0);
	%eY = getWord(%evec,1);
	%eZ = getWord(%evec,2);
	%eXY = mSqrt(%eX*%eX+%eY*%eY);
	%aimVec = %fX*%eXY SPC %fY*%eXY SPC %eZ;
	%end = vectorAdd(%start,vectorScale(%aimVec,%range));
	%ray = containerRayCast(%start,%end,$TypeMasks::All,%obj);
	%target = firstWord(%ray);
	if(isObject(%target))
	{
		%pos = posFromRaycast(%ray);
		%dist = vectorDist(%obj.getPosition(),%pos);
	}
	%initVelocity = vectorScale(%obj.getMuzzleVector(%slot),18.25);
	%initVelocity = vectorAdd(%initVelocity,getRandom(0,3) / 6 SPC getRandom(0,3) / 6 SPC %dist/3.75);
	%p = new (%this.projectileType)()
	{
		dataBlock = %this.projectile;
		initialVelocity = %initVelocity;
		initialPosition = %obj.getMuzzlePoint(%slot);
		sourceObject = %obj;
		sourceSlot = %slot;
		client = %obj.client;
	};
	MissionCleanup.add(%p);
	%obj.lastMortarFire = getSimTime();
	return %p;
}
function MortarImage::onMount(%this,%obj,%slot)
{
	Parent::onMount(%this,%obj,%slot);	
	%obj.playThread(0, armreadyboth);
}

function MortarImage::onUnMount(%this,%obj,%slot)
{
	Parent::onMount(%this,%obj,%slot);	
	%obj.playThread(0, root);
}